% Replication file for
% "Who Should Be Treated?
%  Welfare Maximization Methods for Treatment Choice"
% by Toru Kitagawa and Aleksey Tetenov
% Average treatment effect estimates
% 2017-11-27

clear all
rng(0); % Starting point for the RNG
cost = false; % switch: take treatment costs into account or not
if (cost)
    tcost = 774;
    diary('jtpa_ate_cost.log');
else
    tcost = 0;
    diary('jtpa_ate.log');
end
fprintf('Treatment cost:\n%d\n',tcost);

% DATA INPUT AND PREPARATION
load('../jtpa_kt.mat')

Y = earnings-tcost.*D;
meanY = mean(Y);
Y = Y - meanY; % demean outcomes
n = length(Y);   % sample size
ps = 2/3; % propensity score

g = Y.*(D/ps - (1-D)/(1-ps)); % elements of W(G) - W(G_0)


bsimax = 3999; % number of bootstrap samples to generate

% ATE
fprintf('ATE:\n%.0f\n',sum(g)/n);

% draw bootstrap samples
bsd = zeros(bsimax,1);
for bsi = 1:bsimax
    bsperm = randi(n,[n 1]);
    gr = g(bsperm,:);
    bsd(bsi) = abs(sum(gr)-sum(g))/n;
end

fprintf('Lower 95%% CI:\n%.0f\n',sum(g)/n - prctile(bsd,95));
fprintf('Upper 95%% CI:\n%.0f\n',sum(g)/n + prctile(bsd,95));
diary off
