* Dataset construction
* Replication file for
* "Who Should Be Treated?
*  Welfare Maximization Methods for Treatment Choice"
* by Toru Kitagawa and Aleksey Tetenov
* 2017-11-27
clear all
set more off


* 1. Construct the list of recids (record ids)
* for the original adult anlaysis sample of 11204 observations
* (the variable defining this sample is not included in the public JTPA files)
* using jtpa.tab downloaded from
* https://dataverse.harvard.edu/dataset.xhtml?persistentId=hdl:1902.1/11300
* DOI: 1902.1/11300
* Replication data for:
* "Instrumental Variables Estimates of the Effect of Subsidized Training 
* on the Quantiles of Trainee Earnings"
* by Alberto Abadie and Joshua Angrist and Guido Imbens (2002)

import delimited jtpa.tab
rename v1 recid
keep recid
sort recid
save sample_recids, replace


* 2. Import variables for these observations from the JTPA public release file
* provided by the W.E. Upjohn Institute for Employment Research
* http://www.upjohn.org/sites/default/files/erdc/data/jtpa_national_evaluation.zip
*
* ra_stat : randomization variable (1==treatment, 2==control)
* bfeduca : education level 
* yearearn : pre-program earnings
use jtpa_national_evaluation/Data/expbif/expbif.dta
destring, replace
keep recid ra_stat bfeduca yearearn
sort recid
save jtpa_bif, replace

* newern01-newern30 : participants' earnings in 30 months follow-up
* using the replacement file
use jtpa_national_evaluation/Data/replacement_files/earns2.dta
destring, replace
egen earnings = rowtotal(newern01-newern30)
keep recid earnings
sort recid
save jtpa_earnings, replace


* 3. Merge the data files
use sample_recids
merge recid using jtpa_bif
keep if _merge==3
drop _merge
sort recid
merge recid using jtpa_earnings
keep if _merge==3
drop _merge


* 4. Rename and recode variables
gen D = (ra_stat==1)
drop ra_stat
rename bfeduca edu
rename yearearn prevearn

 
* 5. Drop observations with missing education or pre-program earnings
drop if edu==99
drop if prevearn==99999

sort recid
saveold ../jtpa_kt.dta, version(12) replace

* 6. Save in tab-delimited format for importing into MATLAB
outsheet recid D earnings prevearn edu using ../jtpa_kt.tab, replace
