% Replication file for
% "Who Should Be Treated?
%  Welfare Maximization Methods for Treatment Choice"
% by Toru Kitagawa and Aleksey Tetenov
% Graph kernel regression rules with different costs
% 2017-11-27

clear all
color = true;
if (color)
    color1 = [0.4 0.1 0.1];
    color2 = [0.7 0.4 0.2];
    color3 = [0.6 0.7 0.6];
    savefilename ='Figure_Kern_color';
else
    color1 = [0    0    0];
    color2 = [0.55 0.55 0.55];
    color3 = [0.8  0.8  0.8];
    savefilename = 'Figure_Kern';
end


% DATA INPUT AND PREPARATION
load('../jtpa_kt.mat')

D  = logical(D);
tcost = 0;    
Y = earnings-tcost.*D;
meanY = mean(Y);
Y = Y - meanY;
tcost = 774;
Y2 = earnings-tcost.*D;
meanY2 = mean(Y2);
Y2 = Y2 - meanY2;
n = length(Y);   % sample size
ps = 2/3; % propensity score
% create regressor matrix X from the data
X  = [edu prevearn];

g = Y.*(D/ps - (1-D)/(1-ps)); % elements of W(G) - W(G_0)
g2 = Y2.*(D/ps - (1-D)/(1-ps));

% Compute kernel regression treatment rule
% ROT bandwidth for Epan. = sigma_j x 2.2 x n^{-1/6} for 2-dim.
h01 = 2.2 * std(X(:,1)) * (sum(1-D)^(-1/6));
h02 = 2.2 * std(X(:,2)) * (sum(1-D)^(-1/6));
h11 = 2.2 * std(X(:,1)) * (sum(D)^(-1/6));
h12 = 2.2 * std(X(:,2)) * (sum(D)^(-1/6));

XT0 = X(~D,:); YT0 = Y(~D);
XT1 = X( D,:); YT1 = Y( D);
kte = zeros(n,1);
for j=1:n
    kw0 = max(0, .75.*(1-(((XT0(:,1)-X(j,1))./h01).^2))).*max(0, .75.*(1-(((XT0(:,2)-X(j,2))./h02).^2)));
    kw1 = max(0, .75.*(1-(((XT1(:,1)-X(j,1))./h11).^2))).*max(0, .75.*(1-(((XT1(:,2)-X(j,2))./h12).^2)));
    % NW Kernel regression
    kte(j,1) = sum(kw1.*YT1)/sum(kw1) - sum(kw0.*YT0)/sum(kw0);
end
% impute zero when the estimate is not defined.
kte(isnan(kte)) = zeros(sum(isnan(kte)),1);

treat1 = (kte>0);
treat2 = (kte>tcost);

% Output for the comparison table
diary('jtpa_Kern.log');
fprintf('Treatment cost:\n%d\n',0);
fprintf('Proportion treated:\n%.2f\n',mean(treat1));
fprintf('Est. welfare gain:\n%.0f\n',mean(g.*treat1));
fprintf('Treatment cost:\n%d\n',tcost);
fprintf('Proportion treated:\n%.2f\n',mean(treat2));
fprintf('Est. welfare gain:\n%.0f\n',mean(g2.*treat2));
diary off

% Prepare the density plot of the covariates
[Xr, Ind] = sortrows(X);
Xu = unique(Xr,'rows');
nu  = size(Xu,1); % number of unique covariate vectors
nw = zeros(nu,1);
jj = 1;
for j = 1:size(Xr,1)
    if ~(sum(Xr(j,:)~=Xu(jj,:)))
        nw(jj) = nw(jj) + 1;
    else
        jj = jj+1;
        nw(jj) = nw(jj) + 1;
    end
end
edu_u = Xu(:,1); 
prevearn_u = Xu(:,2);

% re-run kernreg
for j = 1:size(Xu,1)
    kw0 = max(0, .75.*(1-(((XT0(:,1)-Xu(j,1))./h01).^2))).*max(0, .75.*(1-(((XT0(:,2)-Xu(j,2))./h02).^2)));
    kw1 = max(0, .75.*(1-(((XT1(:,1)-Xu(j,1))./h11).^2))).*max(0, .75.*(1-(((XT1(:,2)-Xu(j,2))./h12).^2)));
    % NW Kernel regression
    kteu(j,1) = sum(kw1.*YT1)/sum(kw1) - sum(kw0.*YT0)/sum(kw0);
end

h = figure('Color','white');

select1 = (kteu>tcost);
scatter(edu_u(select1),prevearn_u(select1),nw(select1),'MarkerEdgeColor','none','MarkerFaceColor',color3);
hold on

select2 = (kteu>0)&(kteu<=tcost);
scatter(edu_u(select2),prevearn_u(select2),nw(select2),'MarkerEdgeColor','none','MarkerFaceColor',color2);

select3 = (kteu<=0);
scatter(edu_u(select3),prevearn_u(select3),nw(select3),'MarkerEdgeColor','none','MarkerFaceColor',color1);

axis([min(edu)-1 max(edu)+1 -2000 25000]);
xlabel('Years of education');
ylabel('Pre-program annual earnings');
ax = gca;
ax.YTick = [0,10000,20000];
ax.YTickLabel = {'$0','$10K','$20K'};
legend('Kernel regression > $774','Kernel regression > $0','Kernel regression < $0','Location','northwest');

saveas(h,savefilename,'epsc');
saveas(h,savefilename,'png');
saveas(h,savefilename,'fig');
