% Replication file for
% "Who Should Be Treated?
%  Welfare Maximization Methods for Treatment Choice"
% by Toru Kitagawa and Aleksey Tetenov
% 2017-11-27
% Plot EWM treatment rules linear in (education, prior earnings)

clear all
color = true;
if (color)
    patch1_edge  = [0.6 0.4 0.1];
    patch1_color = [0.93 0.79 0.57];
    patch2_edge  = [0.3 0.4 0.3];
    patch2_color = [0.6 0.7 0.6];
    Face2Alpha    = 0.7;
    savefilename ='Figure_EWML_color';
else
    patch1_edge  = [0.2 0.2 0.2];
    patch1_color = [0.5 0.5 0.5];
    patch2_edge  = [0.5 0.5 0.5];
    patch2_color = [0.8 0.8 0.8];
    Face2Alpha    = 0.7;
    savefilename = 'Figure_EWML';
end

% DATA INPUT AND PREPARATION
load('jtpa_linear_results.mat');
beta1 = beta;
load('jtpa_linear_cost_coefs.mat','beta');
beta2 = beta;

% Prepare the density plot of the covariates
[Xr, Ind] = sortrows(X);
Xu = unique(Xr,'rows');
nu  = size(Xu,1); % number of unique covariate vectors
nw = zeros(nu,1);
jj = 1;
for j = 1:size(Xr,1)
    if ~(sum(Xr(j,:)~=Xu(jj,:)))
        nw(jj) = nw(jj) + 1;
    else
        jj = jj+1;
        nw(jj) = nw(jj) + 1;
    end
end
edu_u = Xu(:,2)*Xscale(1,1); 
prevearn_u = Xu(:,3)*Xscale(1,2);

h = figure('Color','white');

line_edu = [min(edu)-0.5:0.01:max(edu)+0.5]';

% Calculate the earnings cutoff at different edu levels
% No cost - using treatment rule with parameters beta1
line_earn1 = Xscale(1,2)*(-(beta1(1) + line_edu*beta1(2)./Xscale(1,1))./beta1(3));

if (beta1(3)>0) % treatment rule is increasing in earnings
    select1 = (line_earn1 <= 25000);
    patch1_X = [line_edu(select1); flipud(line_edu(select1))];
    patch1_Y = [max(line_earn1(select1),-1000); 25000*ones(sum(select1),1)];
else            % treatment rule is decreasing in earnings
    select1 = (line_earn1 >= -1000);
    patch1_X = [line_edu(select1); flipud(line_edu(select1))];
    patch1_Y = [min(line_earn1(select1),25000); -1000*ones(sum(select1),1)];
end
patch(patch1_X,patch1_Y,patch1_color,'LineStyle','-','FaceAlpha',Face2Alpha,'EdgeColor',patch1_edge);
hold on

% prepare patch 2
% Calculate the earnings cutoff at different edu levels
% With cost - using treatment rule with parameters beta2
line_earn2 = Xscale(1,2)*(-(beta2(1) + line_edu*beta2(2)./Xscale(1,1))./beta2(3));

if (beta2(3)>0) % treatment rule is increasing in earnings
    select2 = (line_earn2 <= 25000);
    patch2_X = [line_edu(select2); flipud(line_edu(select2))];
    patch2_Y = [max(line_earn2(select2),-1000); 25000*ones(sum(select2),1)];
else            % treatment rule is decreasing in earnings
    select2 = (line_earn2 >= -1000);
    patch2_X = [line_edu(select2); flipud(line_edu(select2))];
    patch2_Y = [min(line_earn2(select2),25000); -1000*ones(sum(select2),1)];
end
patch(patch2_X,patch2_Y,patch2_color,'LineStyle','-','FaceAlpha',Face2Alpha,'EdgeColor',patch2_edge);

% overlay the density plot of the covariates
scatter(edu_u,prevearn_u,nw,'MarkerEdgeColor','none','MarkerFaceColor','black');

% plot labeling
axis([min(edu)-1 max(edu)+1 -2000 25000]);
xlabel('Years of education');
ylabel('Pre-program annual earnings');
ax = gca;
ax.YTick = [0,10000,20000];
ax.YTickLabel = {'$0','$10K','$20K'};
legend('EWM rule, no cost','EWM rule, $774 cost per assignee','Population density','Location','northwest');

saveas(h,savefilename,'epsc');
saveas(h,savefilename,'png');
saveas(h,savefilename,'fig');
