% Replication file for
% "Who Should Be Treated?
%  Welfare Maximization Methods for Treatment Choice"
% by Toru Kitagawa and Aleksey Tetenov
% 2017-11-24
% Plot quadrant EWM treatment rules in (education, prior earnings)

clear all
color = true;
if (color)
    patch1_edge  = [0.6 0.4 0.1];
    patch1_color = [0.93 0.79 0.57];
    patch2_edge  = [0.3 0.4 0.3];
    patch2_color = [0.6 0.7 0.6];
    Face2Alpha    = 0.7;
    savefilename ='Figure_EWMQ_color';
else
    patch1_edge  = [0.2 0.2 0.2];
    patch1_color = [0.5 0.5 0.5];
    patch2_edge  = [0.5 0.5 0.5];
    patch2_color = [0.8 0.8 0.8];
    Face2Alpha    = 0.7;
    savefilename = 'Figure_EWMQ';
end

% DATA INPUT AND PREPARATION
load('jtpa_quad_results.mat');
beta1 = beta;
load('jtpa_quad_cost_coefs.mat','beta');
beta2 = beta;

% Prepare the density plot of the covariates
[Xr, Ind] = sortrows(X);
Xu = unique(Xr,'rows');
nu  = size(Xu,1); % number of unique covariate vectors
nw = zeros(nu,1);
jj = 1;
for j = 1:size(Xr,1)
    if ~(sum(Xr(j,:)~=Xu(jj,:)))
        nw(jj) = nw(jj) + 1;
    else
        jj = jj+1;
        nw(jj) = nw(jj) + 1;
    end
end
edu_u = Xu(:,2)*Xscale(1,1); 
prevearn_u = Xu(:,3)*Xscale(1,2);

in_Ghat1 = ((X(:,[1 2])*beta1(1:2)>0) & (X(:,[1 3])*beta1(3:4)>0));
in_Ghat2 = ((X(:,[1 2])*beta2(1:2)>0) & (X(:,[1 3])*beta2(3:4)>0));

h = figure('Color','white');

treat1_min1 = min(edu(in_Ghat1,:))-.5; treat1_max1 = max(edu(in_Ghat1,:))+.5;
treat1_min2 = min(prevearn(in_Ghat1,:)); treat1_max2 = min(max(prevearn(in_Ghat1,:)),25000);
if (treat1_min2 == 0)
    treat1_min2 = -1000;
end
patch1_X = [treat1_min1 treat1_min1 treat1_max1 treat1_max1];
patch1_Y = [treat1_min2 treat1_max2 treat1_max2 treat1_min2];
patch(patch1_X,patch1_Y,patch1_color,'LineStyle','-','FaceAlpha',Face2Alpha,'EdgeColor',patch1_edge);
hold on

% prepare patch 2
treat2_min1 = min(edu(in_Ghat2,:))-.5; treat2_max1 = max(edu(in_Ghat2,:))+.5;
treat2_min2 = min(prevearn(in_Ghat2,:)); treat2_max2 = min(max(prevearn(in_Ghat2,:)),25000);
if (treat2_min2 == 0)
    treat2_min2 = -1000;
end
patch2_X = [treat2_min1 treat2_min1 treat2_max1 treat2_max1];
patch2_Y = [treat2_min2 treat2_max2 treat2_max2 treat2_min2];
patch(patch2_X,patch2_Y,patch2_color,'LineStyle','-','FaceAlpha',Face2Alpha,'EdgeColor',patch2_edge);

% overlay the density plot of the covariates
scatter(edu_u,prevearn_u,nw,'MarkerEdgeColor','none','MarkerFaceColor','black');

% plot labeling
axis([min(edu)-1 max(edu)+1 -2000 25000]);
xlabel('Years of education');
ylabel('Pre-program annual earnings');
ax = gca;
ax.YTick = [0,10000,20000];
ax.YTickLabel = {'$0','$10K','$20K'};
legend('EWM rule, no cost','EWM rule, $774 cost per assignee','Population density','Location','northwest');

saveas(h,savefilename,'epsc');
saveas(h,savefilename,'png');
saveas(h,savefilename,'fig');
